Learn R Programming

RYandexTranslate (version 1.0)

get_translation_direction: Gets a list of translation directions supported by the service

Description

Gets a list of translation directions supported by the service

Usage

get_translation_direction(api_key, lang = "")

Arguments

api_key
yandex API key
lang
If set, the response contains explanations of language codes. Language names are output in the language corresponding to the code in this parameter.

Value

  • data frame giving supported translation direction

Examples

Run this code
data=get_translation_direction(api_key)

Run the code above in your browser using DataLab